summary refs log tree commit diff
path: root/pkgs
diff options
context:
space:
mode:
authorworldofpeace <worldofpeace@protonmail.ch>2020-02-09 23:49:42 +0100
committerFlorian Klink <flokli@flokli.de>2020-02-09 23:53:58 +0100
commitd3efeb79b7059cf38d1baae03f2104b7a28dda36 (patch)
tree6814cd6cbcf63b4ee7797b639dd9c4086fe971cd /pkgs
parent6022db4d9d9df3bad37d5c41daa0a1db8bf6e660 (diff)
downloadnixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar.gz
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar.bz2
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar.lz
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar.xz
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.tar.zst
nixpkgs-d3efeb79b7059cf38d1baae03f2104b7a28dda36.zip
nixosTest: update to make-test-python.nix
This still referred to the legacy make-test.nix (Perl)
Diffstat (limited to 'pkgs')
-rw-r--r--pkgs/top-level/all-packages.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index 0c9b909a9d0..e16165bb698 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -25033,7 +25033,7 @@ in
   /*
    * Run a NixOS VM network test using this evaluation of Nixpkgs.
    *
    * It is mostly equivalent to `import ./make-test.nix` from the
    * NixOS manual[1], except that your `pkgs` will be used instead of
    * letting NixOS invoke Nixpkgs again. If a test machine needs to
    * set NixOS options under `nixpkgs`, it must set only the
@@ -25059,11 +25059,11 @@ in
    */
   nixosTest =
     let
       /* The nixos/lib/testing.nix module, preapplied with arguments that
        * make sense for this evaluation of Nixpkgs.
        */
       nixosTesting =
-        (import ../../nixos/lib/testing.nix {
+        (import ../../nixos/lib/testing-python.nix {
           inherit (pkgs.stdenv.hostPlatform) system;
           inherit pkgs;
           extraConfigurations = [(
@@ -25033,7 +25033,7 @@ in
    * Run a NixOS VM network test using this evaluation of Nixpkgs.
    *
-   * It is mostly equivalent to `import ./make-test.nix` from the
+   * It is mostly equivalent to `import ./make-test-python.nix` from the
    * NixOS manual[1], except that your `pkgs` will be used instead of
    * letting NixOS invoke Nixpkgs again. If a test machine needs to
@@ -25059,11 +25059,11 @@ in
   nixosTest =
     let
-      /* The nixos/lib/testing.nix module, preapplied with arguments that
+      /* The nixos/lib/testing-python.nix module, preapplied with arguments that
        * make sense for this evaluation of Nixpkgs.
        */